summaryrefslogtreecommitdiff
path: root/src/lib/subtitle_decoder.cc
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/subtitle_decoder.cc')
-rw-r--r--src/lib/subtitle_decoder.cc11
1 files changed, 9 insertions, 2 deletions
diff --git a/src/lib/subtitle_decoder.cc b/src/lib/subtitle_decoder.cc
index d20196a63..533668616 100644
--- a/src/lib/subtitle_decoder.cc
+++ b/src/lib/subtitle_decoder.cc
@@ -62,8 +62,15 @@ SubtitleDecoder::get (list<T> const & subs, list<ContentTimePeriod> const & sp,
return list<T> ();
}
- /* Seek if what we want is before what we have, or more than a reasonable amount after */
- if (subs.empty() || sp.back().to < subs.front().period().from || sp.front().from > (subs.back().period().to + ContentTime::from_seconds (5))) {
+ /* Seek if what we want is before what we have, or a more than a little bit after.
+ Be careful with the length of this `little bit'; consider the case where the last
+ subs were just less than this little bit B ago. Then we will not seek, but instead
+ pass() for nearly B seconds; if we are a FFmpegDecoder then this will generate B's
+ worth of video which will stack up. If B + the pre-roll is bigger than the maximum
+ number of frames that the VideoDecoder will keep then we will get an assertion
+ failure in VideoDecoder.
+ */
+ if (subs.empty() || sp.back().to < subs.front().period().from || sp.front().from > (subs.back().period().to + ContentTime::from_seconds (1))) {
seek (sp.front().from, true);
}